@@ -18,6 +18,10 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <tqcheckbox.h>
 #include <tqlabel.h>
 #include <tqlayout.h>
@@ -56,11 +60,6 @@
 
 #include "displayconfig.h"
 
-using namespace std;
-#ifdef __OpenBSD__
-#define abs __gnu_cxx::abs
-#endif
-
 /**** DLL Interface ****/
 typedef KGenericFactory<KDisplayConfig, TQWidget> KDisplayCFactory;
 K_EXPORT_COMPONENT_FACTORY( kcm_displayconfig, KDisplayCFactory("kcmdisplayconfig") )
@@ -449,8 +448,7 @@ void KDisplayConfig::updateDraggableMonitorInformationInternal (int monitor_id,
 		return;
 	}
 
-	TQString rotationDesired = *screendata->rotations.at(screendata->current_rotation_index);
-	bool isvisiblyrotated = ((rotationDesired == ROTATION_90_DEGREES_STRING) || (rotationDesired == ROTATION_270_DEGREES_STRING));
+	bool isvisiblyrotated = (screendata->current_rotation_index == ROTATION_90_DEGREES_INDEX) || (screendata->current_rotation_index == ROTATION_270_DEGREES_INDEX);
 
 	if (screendata->is_extended) {
 		moved_monitor->show();
@@ -745,7 +743,7 @@ void KDisplayConfig::setRealResolutionSliderValue(int index) {
 KDisplayConfig::KDisplayConfig(TQWidget *parent, const char *name, const TQStringList &)
   : TDECModule(KDisplayCFactory::instance(), parent, name), iccTab(0), numberOfProfiles(0), numberOfScreens(0), m_randrsimple(0), activeProfileName(""), m_gammaApplyTimer(0)
 {
-#ifdef __TDE_HAVE_TDEHWLIB
+#ifdef WITH_TDEHWLIB
 	TDEHardwareDevices *hwdevices = TDEGlobal::hardwareDevices();
 	connect(hwdevices, TQT_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQT_SLOT(deviceChanged(TDEGenericDevice*)));
 #endif
@@ -864,7 +862,7 @@ KDisplayConfig::~KDisplayConfig()
 }
 
 void KDisplayConfig::deviceChanged (TDEGenericDevice* device) {
-#ifdef __TDE_HAVE_TDEHWLIB
+#ifdef WITH_TDEHWLIB
 	if (device->type() == TDEGenericDeviceType::Monitor) {
 		if (base->rescanHardware->isEnabled()) {
 			base->rescanHardware->setEnabled(false);
@@ -987,7 +985,7 @@ void KDisplayConfig::loadProfileFromDiskHelper(bool forceReload) {
 
 void KDisplayConfig::selectProfile (int slotNumber) {
 	TQString selectedProfile = base->displayProfileList->currentText();
-	if (selectedProfile == "<default>") {
+	if (selectedProfile == i18n("<default>")) {
 		selectedProfile = "";
 	}
 	activeProfileName = selectedProfile;
@@ -1142,7 +1140,7 @@ void KDisplayConfig::updateStartupProfileLabel()
 {
 	TQString friendlyName = startupProfileName;
 	if (friendlyName == "") {
-		friendlyName = "<default>";
+		friendlyName = i18n("<default>");
 	}
 
 	base->startupDisplayProfileList->setCurrentItem(friendlyName, false);
@@ -1151,7 +1149,7 @@ void KDisplayConfig::updateStartupProfileLabel()
 void KDisplayConfig::selectDefaultProfile(int slotNumber)
 {
 	TQString selectedProfile = base->startupDisplayProfileList->currentText();
-	if (selectedProfile == "<default>") {
+	if (selectedProfile == i18n("<default>")) {
 		selectedProfile = "";
 	}
 
@@ -1233,11 +1231,10 @@ void KDisplayConfig::updateDisplayedInformation () {
 		base->orientationVFlip->setChecked(screendata->has_y_flip);
 	}
 	else {
-		base->rotationSelectDD->insertItem(ROTATION_0_DEGREES_STRING, 0);
+		base->rotationSelectDD->insertItem(screendata->rotations[ROTATION_0_DEGREES_INDEX], ROTATION_0_DEGREES_INDEX);
 		base->rotationSelectDD->setCurrentItem(0);
 		base->orientationHFlip->hide();
 		base->orientationVFlip->hide();
-
 	}
 	base->rotationSelectDD->blockSignals(false);
 	base->orientationHFlip->blockSignals(false);
@@ -1350,8 +1347,7 @@ void KDisplayConfig::updateDragDropDisplay() {
 		for (i=0;i<numberOfScreens;i++) {
 			screendata = m_screenInfoArray[activeProfileName].at(i);
 			if (((j==0) && (screendata->is_primary==true)) || ((j==1) && (screendata->is_primary==false))) {	// This ensures that the primary monitor is always the first one created and placed on the configuration widget
-				TQString rotationDesired = *screendata->rotations.at(screendata->current_rotation_index);
-				bool isvisiblyrotated = ((rotationDesired == ROTATION_90_DEGREES_STRING) || (rotationDesired == ROTATION_270_DEGREES_STRING));
+				bool isvisiblyrotated = ((screendata->current_rotation_index == ROTATION_90_DEGREES_INDEX) || (screendata->current_rotation_index == ROTATION_270_DEGREES_INDEX));
 				DraggableMonitor *m = new DraggableMonitor( base->monitorPhyArrange, 0, WStyle_Customize | WDestructiveClose | WStyle_NoBorder | WX11BypassWM );
 				connect(m, TQT_SIGNAL(workspaceRelayoutNeeded()), this, TQT_SLOT(layoutDragDropDisplay()));
 				connect(m, TQT_SIGNAL(monitorSelected(int)), this, TQT_SLOT(selectScreen(int)));
@@ -1698,7 +1694,7 @@ void KDisplayConfig::createHotplugRulesGrid() {
 		}
 		KComboBox* combo = new KComboBox(base->profileRulesGridWidget, (TQString("%1").arg(i)).ascii());
 		connect(combo, TQT_SIGNAL(activated(int)), this, TQT_SLOT(changed()));
-		combo->insertItem("<default>");
+		combo->insertItem(i18n("<default>"));
 		for (TQStringList::Iterator it3 = availableProfileNames.begin(); it3 != availableProfileNames.end(); ++it3) {
 			combo->insertItem(*it3);
 		}
@@ -1803,8 +1799,8 @@ void KDisplayConfig::profileListChanged() {
 	// Clear and reload the combo boxes
 	base->displayProfileList->clear();
 	base->startupDisplayProfileList->clear();
-	base->displayProfileList->insertItem("<default>");
-	base->startupDisplayProfileList->insertItem("<default>");
+	base->displayProfileList->insertItem(i18n("<default>"));
+	base->startupDisplayProfileList->insertItem(i18n("<default>"));
 	for (TQStringList::Iterator it = availableProfileNames.begin(); it != availableProfileNames.end(); ++it) {
 		base->displayProfileList->insertItem(*it);
 		base->startupDisplayProfileList->insertItem(*it);
