@@ -48,7 +48,7 @@ extern KSimpleConfig *config;
 TDMUsersWidget::TDMUsersWidget(TQWidget *parent, const char *name)
     : TQWidget(parent, name)
 {
-#ifdef __linux__
+#ifdef Q_OS_LINUX
     struct stat st;
     if (!stat( "/etc/debian_version", &st )) {	/* debian */
 	defminuid = "1000";
@@ -66,10 +66,18 @@ TDMUsersWidget::TDMUsersWidget(TQWidget *parent, const char *name)
 	defminuid = "500";
 	defmaxuid = "65000";
     }
-#else
+#elif defined(Q_OS_SOLARIS)
+    struct stat st;
+    if (stat( "/etc/dilos_version_build", &st ) == 0) { /* DilOS */
+	defminuid = "1000";
+    } else { /* other illumos distro */
+	defminuid = "100";
+    }
+    defmaxuid = "60000";
+#else /* default */
     defminuid = "1000";
     defmaxuid = "65000";
-#endif
+#endif /* default */
 
     // We assume that $kde_datadir/tdm exists, but better check for pics/ and pics/users,
     // and create them if necessary.
@@ -264,7 +272,7 @@ void TDMUsersWidget::slotUserSelected()
 	rstuserbutton->setEnabled( false );
     }
     if (!p.isNull()) {
-	    userbutton->setPixmap( p.smoothScale( 48, 48, TQ_ScaleMin ) );
+	    userbutton->setPixmap( p.smoothScale( 48, 48, TQImage::ScaleMin ) );
     }
 }
 
@@ -288,7 +296,7 @@ void TDMUsersWidget::changeUserPix(const TQString &pix)
 	return;
     }
 
-    p = p.smoothScale( 48, 48, TQ_ScaleMin );
+    p = p.smoothScale( 48, 48, TQImage::ScaleMin );
     TQString userpix = m_userPixDir + user + ".face.icon";
     if (!p.save( userpix, "PNG" ))
         KMessageBox::sorry(this,
