@@ -21,11 +21,6 @@ AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *****************************************************************
-
-    Additional changes:
-    - 2013/10/22 Michele Calgaro
-      * added support for display mode (Icons and Text, Text only, Icons only)
-        and removed "Show application icons"
 */
 
 #include <math.h>
@@ -54,7 +49,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "taskbar.h"
 #include "taskbar.moc"
 
-#define READ_MERGED_TASBKAR_SETTING(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->x():m_settingsObject->x())
+#define READ_MERGED_TASKBAR_SETTING(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->x():m_settingsObject->x())
 
 TaskBar::TaskBar( TaskBarSettings* settingsObject, TaskBarSettings* globalSettingsObject, TQWidget *parent, const char *name )
     : Panner( parent, name ),
@@ -86,7 +81,7 @@ TaskBar::TaskBar( TaskBarSettings* settingsObject, TaskBarSettings* globalSettin
 
     // init
     setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
-    m_sortByAppPrev = READ_MERGED_TASBKAR_SETTING(sortByApp);
+    m_sortByAppPrev = READ_MERGED_TASKBAR_SETTING(sortByApp);
 
     // setup animation frames
     for (int i = 1; i < 11; i++)
@@ -179,31 +174,40 @@ KTextShadowEngine *TaskBar::textShadowEngine()
     return m_textShadowEngine;
 }
 
+int TaskBar::buttonHeight() const
+{
+    TQFontMetrics fm(TDEGlobalSettings::taskbarFont());
+    int bh = TQMAX(fm.height(), READ_MERGED_TASKBAR_SETTING(minimumButtonHeight));
+
+    if(showIcons())
+    {
+        bh = TQMAX(bh, READ_MERGED_TASKBAR_SETTING(iconSize));
+    }
+
+    return bh + 2;
+}
+
+int TaskBar::buttonWidth() const
+{
+    return TQMAX(BUTTON_MIN_WIDTH, READ_MERGED_TASKBAR_SETTING(iconSize)) + 2;
+}
+
 
 TQSize TaskBar::sizeHint() const
 {
-    // get our minimum height based on the minimum button height or the
-    // height of the font in use, which is largest
-    TQFontMetrics fm(TDEGlobalSettings::taskbarFont());
-    int minButtonHeight = fm.height() > READ_MERGED_TASBKAR_SETTING(minimumButtonHeight) ?
-                          fm.height() : READ_MERGED_TASBKAR_SETTING(minimumButtonHeight);
-
-    return TQSize(BUTTON_MIN_WIDTH, minButtonHeight);
+    return TQSize(buttonWidth(), buttonHeight());
 }
 
 TQSize TaskBar::sizeHint( KPanelExtension::Position p, TQSize maxSize) const
 {
-    // get our minimum height based on the minimum button height or the
-    // height of the font in use, which is largest
-    TQFontMetrics fm(TDEGlobalSettings::taskbarFont());
-    int minButtonHeight = fm.height() > READ_MERGED_TASBKAR_SETTING(minimumButtonHeight) ?
-                          fm.height() : READ_MERGED_TASBKAR_SETTING(minimumButtonHeight);
+    // get our minimum height based on the minimum button height, the icon size or the
+    // height of the font in use, whichever is largest
 
     if ( p == KPanelExtension::Left || p == KPanelExtension::Right )
     {
         // Vertical layout
         // Minimum space allows for one icon, the window list button and the up/down scrollers
-        int minHeight = minButtonHeight*3;
+        int minHeight = buttonHeight()*3;
         if (minHeight > maxSize.height())
             return maxSize;
         return TQSize(maxSize.width(), minHeight);
@@ -212,7 +216,7 @@ TQSize TaskBar::sizeHint( KPanelExtension::Position p, TQSize maxSize) const
     {
         // Horizontal layout
         // Minimum space allows for one column of icons, the window list button and the left/right scrollers
-        int min_width=BUTTON_MIN_WIDTH*3;
+        int min_width=buttonWidth()*3;
         if (min_width > maxSize.width())
             return maxSize;
         return TQSize(min_width, maxSize.height());
@@ -238,16 +242,18 @@ void TaskBar::configure()
     bool wasDisplayIconsNText = m_displayIconsNText;
     bool wasShowOnlyIconified = m_showOnlyIconified;
     int  wasShowTaskStates = m_showTaskStates;
+    int  wasIconSize = m_iconSize;
 
-    m_showAllWindows = READ_MERGED_TASBKAR_SETTING(showAllWindows);
-    m_sortByDesktop = m_showAllWindows && READ_MERGED_TASBKAR_SETTING(sortByDesktop);
-    m_displayIconsNText = READ_MERGED_TASBKAR_SETTING(displayIconsNText);
-    m_showOnlyIconified = READ_MERGED_TASBKAR_SETTING(showOnlyIconified);
-    m_cycleWheel = READ_MERGED_TASBKAR_SETTING(cycleWheel);
-    m_showTaskStates = READ_MERGED_TASBKAR_SETTING(showTaskStates);
+    m_showAllWindows = READ_MERGED_TASKBAR_SETTING(showAllWindows);
+    m_sortByDesktop = m_showAllWindows && READ_MERGED_TASKBAR_SETTING(sortByDesktop);
+    m_displayIconsNText = READ_MERGED_TASKBAR_SETTING(displayIconsNText);
+    m_showOnlyIconified = READ_MERGED_TASKBAR_SETTING(showOnlyIconified);
+    m_cycleWheel = READ_MERGED_TASKBAR_SETTING(cycleWheel);
+    m_showTaskStates = READ_MERGED_TASKBAR_SETTING(showTaskStates);
+    m_iconSize = READ_MERGED_TASKBAR_SETTING(iconSize);
 
     m_currentScreen = -1;    // Show all screens or re-get our screen
-    m_showOnlyCurrentScreen = (READ_MERGED_TASBKAR_SETTING(showCurrentScreenOnly) &&
+    m_showOnlyCurrentScreen = (READ_MERGED_TASKBAR_SETTING(showCurrentScreenOnly) &&
                               TQApplication::desktop()->isVirtualDesktop() &&
                               TQApplication::desktop()->numScreens() > 1);
 
@@ -269,7 +275,8 @@ void TaskBar::configure()
         wasDisplayIconsNText != m_displayIconsNText ||
         wasCycleWheel != m_cycleWheel ||
         wasShowOnlyIconified != m_showOnlyIconified ||
-        wasShowTaskStates != m_showTaskStates)
+        wasShowTaskStates != m_showTaskStates ||
+        wasIconSize != m_iconSize)
     {
         // relevant settings changed, update our task containers
         for (TaskContainer::Iterator it = containers.begin();
@@ -280,12 +287,12 @@ void TaskBar::configure()
         }
     }
 
-    if (m_sortByAppPrev != READ_MERGED_TASBKAR_SETTING(sortByApp)) {
-        m_sortByAppPrev = READ_MERGED_TASBKAR_SETTING(sortByApp);
+    if (m_sortByAppPrev != READ_MERGED_TASKBAR_SETTING(sortByApp)) {
+        m_sortByAppPrev = READ_MERGED_TASKBAR_SETTING(sortByApp);
         reSort();
     }
 
-    TaskManager::the()->setXCompositeEnabled(READ_MERGED_TASBKAR_SETTING(showThumbnails));
+    TaskManager::the()->setXCompositeEnabled(READ_MERGED_TASKBAR_SETTING(showThumbnails));
 
     reLayoutEventually();
 }
@@ -414,7 +421,7 @@ void TaskBar::showTaskContainer(TaskContainer* container)
     }
 
     // try to place the container after one of the same app
-    if (READ_MERGED_TASBKAR_SETTING(sortByApp))
+    if (READ_MERGED_TASKBAR_SETTING(sortByApp))
     {
         TaskContainer::Iterator it = containers.begin();
         for (; it != containers.end(); ++it)
@@ -736,14 +743,12 @@ void TaskBar::reLayout()
     // number of rows simply depends on our height which is either the
     // minimum button height or the height of the font in use, whichever is
     // largest
-    TQFontMetrics fm(TDEGlobalSettings::taskbarFont());
-    int minButtonHeight = fm.height() > READ_MERGED_TASBKAR_SETTING(minimumButtonHeight) ?
-                          fm.height() : READ_MERGED_TASBKAR_SETTING(minimumButtonHeight);
+    int minButtonHeight = buttonHeight();
 
     // horizontal layout
     if (orientation() == Qt::Horizontal)
     {
-        int bwidth=BUTTON_MIN_WIDTH;
+        int bwidth=buttonWidth();
         int rows = contentsRect().height() / minButtonHeight;
         if (rows<1)
           rows=1;
@@ -757,20 +762,20 @@ void TaskBar::reLayout()
         int bpr = static_cast<int>(ceil(static_cast<double>(list.count()) / rows));
 
         // adjust content size
-        if ( contentsRect().width() < bpr * BUTTON_MIN_WIDTH )
+        if ( contentsRect().width() < bpr * bwidth )
         {
-            resizeContents( bpr * BUTTON_MIN_WIDTH, contentsRect().height() );
+            resizeContents( bpr * bwidth, contentsRect().height() );
         }
 
         // maximum number of buttons per row
-        int mbpr = contentsRect().width() / BUTTON_MIN_WIDTH;
+        int mbpr = contentsRect().width() / bwidth;
 
         // expand button width if space permits and the taskbar is not in 'icons only' mode
         if (mbpr > bpr)
         {
             if (!showIcons() || showText())
               bwidth = contentsRect().width() / bpr;
-            int maxWidth = READ_MERGED_TASBKAR_SETTING(maximumButtonWidth);
+            int maxWidth = READ_MERGED_TASKBAR_SETTING(maximumButtonWidth);
             if (maxWidth > 0 && bwidth > maxWidth)
             {
                 bwidth = maxWidth;
@@ -992,9 +997,7 @@ int TaskBar::taskCount() const
 
 int TaskBar::maximumButtonsWithoutShrinking() const
 {
-    TQFontMetrics fm(TDEGlobalSettings::taskbarFont());
-    int minButtonHeight = fm.height() > READ_MERGED_TASBKAR_SETTING(minimumButtonHeight) ?
-                          fm.height() : READ_MERGED_TASBKAR_SETTING(minimumButtonHeight);
+    int minButtonHeight = buttonHeight();
     int rows = contentsRect().height() / minButtonHeight;
 
     if (rows < 1)
@@ -1004,7 +1007,7 @@ int TaskBar::maximumButtonsWithoutShrinking() const
 
     if ( orientation() == Qt::Horizontal ) {
         // maxWidth of 0 means no max width, drop back to default
-        int maxWidth = READ_MERGED_TASBKAR_SETTING(maximumButtonWidth);
+        int maxWidth = READ_MERGED_TASKBAR_SETTING(maximumButtonWidth);
         if (maxWidth == 0)
         {
             maxWidth = BUTTON_MAX_WIDTH;
@@ -1022,8 +1025,8 @@ int TaskBar::maximumButtonsWithoutShrinking() const
 
 bool TaskBar::shouldGroup() const
 {
-    return READ_MERGED_TASBKAR_SETTING(groupTasks) == m_settingsObject->GroupAlways ||
-           ((READ_MERGED_TASBKAR_SETTING(groupTasks) == m_settingsObject->GroupWhenFull &&
+    return READ_MERGED_TASKBAR_SETTING(groupTasks) == m_settingsObject->GroupAlways ||
+           ((READ_MERGED_TASKBAR_SETTING(groupTasks) == m_settingsObject->GroupWhenFull &&
              taskCount() > maximumButtonsWithoutShrinking()));
 }
 
@@ -1171,7 +1174,7 @@ void TaskBar::activateNextTask(bool forward)
 void TaskBar::wheelEvent(TQWheelEvent* e)
 {
 
-    if(READ_MERGED_TASBKAR_SETTING(cycleWheel)) {
+    if(READ_MERGED_TASKBAR_SETTING(cycleWheel)) {
 
         if (e->delta() > 0)
         {
@@ -1251,7 +1254,7 @@ TQImage* TaskBar::blendGradient(const TQSize& size)
 
 void TaskBar::sortContainersByDesktop(TaskContainer::List& list)
 {
-    typedef TQValueVector<QPair<int, QPair<int, TaskContainer*> > > SortVector;
+    typedef TQValueVector<TQPair<int, TQPair<int, TaskContainer*> > > SortVector;
     SortVector sorted;
     sorted.resize(list.count());
     int i = 0;
