@@ -118,9 +118,6 @@ private:
 };
 
 extern bool tqt_qclipboard_bailout_hack;
-#if KDE_IS_VERSION( 15, 0, 0 )
-#error Check status of #80072 with Qt4.
-#endif
 
 static void ensureGlobalSyncOff(TDEConfig* config);
 
@@ -1056,10 +1053,10 @@ bool KlipperWidget::ignoreClipboardChanges() const
     TQWidget *focusWidget = tqApp->focusWidget();
     if ( focusWidget )
     {
-        if ( focusWidget->inherits( TQSPINBOX_OBJECT_NAME_STRING ) ||
+        if ( focusWidget->inherits( "TQSpinBox" ) ||
              (focusWidget->parentWidget() &&
-              focusWidget->inherits(TQLINEEDIT_OBJECT_NAME_STRING) &&
-              focusWidget->parentWidget()->inherits(TQSPINWIDGET_OBJECT_NAME_STRING)) )
+              focusWidget->inherits("TQLineEdit") &&
+              focusWidget->parentWidget()->inherits("TQSpinWidget")) )
         {
             return true;
         }
