@@ -348,8 +348,6 @@ KonqKfmIconView::KonqKfmIconView( TQWidget *parentWidget, TQObject *parent, cons
              this, TQT_SLOT( slotMouseButtonClicked(int, TQIconViewItem*, const TQPoint&)) );
     connect( m_pIconView, TQT_SIGNAL( contextMenuRequested(TQIconViewItem*, const TQPoint&)),
              this, TQT_SLOT( slotContextMenuRequested(TQIconViewItem*, const TQPoint&)) );
-    connect( m_pIconView, TQT_SIGNAL( mouseDoubleClicked(TQIconViewItem*)),
-             this, TQT_SLOT( slotDoubleClicked(TQIconViewItem*)) );
 
     // Signals needed to implement the spring loading folders behavior
     connect( m_pIconView, TQT_SIGNAL( held( TQIconViewItem * ) ),
@@ -412,6 +410,8 @@ KonqKfmIconView::KonqKfmIconView( TQWidget *parentWidget, TQObject *parent, cons
     //    m_pIconView->calculateGridX();
 
     setViewMode( mode );
+
+    m_pActivateDoubleClickTimer = new TQTimer(this);
 }
 
 KonqKfmIconView::~KonqKfmIconView()
@@ -427,6 +427,13 @@ KonqKfmIconView::~KonqKfmIconView()
     delete m_pProps;
     //no need for that, KParts deletes our widget already ;-)
     //    delete m_pIconView;
+    m_pActivateDoubleClickTimer->stop();
+    delete m_pActivateDoubleClickTimer;
+    if (m_pTimeoutRefreshTimer)
+    {
+      m_pTimeoutRefreshTimer->stop();
+      delete m_pTimeoutRefreshTimer;
+    }
 }
 
 const KFileItem * KonqKfmIconView::currentItem()
@@ -436,7 +443,7 @@ const KFileItem * KonqKfmIconView::currentItem()
 
 void KonqKfmIconView::slotPreview( bool toggle )
 {
-    TQCString name = TQT_TQOBJECT_CONST(sender())->name(); // e.g. clipartthumbnail (or audio/, special case)
+    TQCString name = sender()->name(); // e.g. clipartthumbnail (or audio/, special case)
     if (name == "iconview_preview_all")
     {
         m_pProps->setShowingPreview( toggle );
@@ -869,21 +876,40 @@ void KonqKfmIconView::slotMouseButtonPressed(int _button, TQIconViewItem* _item,
 
 void KonqKfmIconView::slotMouseButtonClicked(int _button, TQIconViewItem* _item, const TQPoint& )
 {
-    if( _button == Qt::MidButton )
+    if (_button == Qt::MidButton)
+    {
         mmbClicked( _item ? static_cast<KFileIVI*>(_item)->item() : 0L );
+    }
+    else if (!_item && _button == Qt::LeftButton)
+    {
+        if (m_pActivateDoubleClickTimer->isActive())
+        {
+            m_pActivateDoubleClickTimer->stop();
+            slotDoubleClicked(_item);
+        }
+        else
+        {
+            m_pActivateDoubleClickTimer->start(TQApplication::doubleClickInterval(), true);
+        }
+    }
 }
 
 void KonqKfmIconView::slotDoubleClicked(TQIconViewItem *_item)
 { 
-    if (!_item)
+    if (!_item && KonqFMSettings::settings()->doubleClickMoveToParent())
     {
         KParts::URLArgs args;
         args.trustedSource = true;
-        KURL upURL = m_dirLister->url().upURL();
+        KURL baseURL(m_dirLister->url().internalReferenceURL());
+        if (baseURL.isEmpty())
+        {
+            baseURL = m_dirLister->url();
+        }
+        KURL upURL = baseURL.upURL();
         if (!upURL.isEmpty())
-	{  
-	m_extension->openURLRequest(upURL, args);
-	}
+        {
+            m_extension->openURLRequest(upURL, args);
+        }
     }
 }
   
