@@ -1,5 +1,3 @@
-// -*- indent-tabs-mode:nil -*-
-// vim: set ts=4 sts=4 sw=4 et:
 /* This file is part of the KDE project
    Copyright (C) 2000 David Faure <faure@kde.org>
    Copyright (C) 2002-2003 Alexander Kellett <lypanov@kde.org>
@@ -394,7 +392,7 @@ void ActionsImpl::slotImport() {
     // kdDebug() << "ActionsImpl::slotImport() where sender()->name() == "
     //           << sender()->name() << endl;
     ImportCommand* import
-        = ImportCommand::performImport(TQT_TQOBJECT_CONST(sender())->name()+6, KEBApp::self());
+        = ImportCommand::performImport(sender()->name()+6, KEBApp::self());
     if (!import)
         return;
     CmdHistory::self()->addCommand(import);
@@ -429,9 +427,9 @@ void ActionsImpl::slotPrint() {
     s_part = KParts::ComponentFactory
                         ::createPartInstanceFromQuery<KParts::ReadOnlyPart>(
                                 "text/html", TQString::null);
-    s_part->setProperty("pluginsEnabled", TQVariant(false, 1));
-    s_part->setProperty("javaScriptEnabled", TQVariant(false, 1));
-    s_part->setProperty("javaEnabled", TQVariant(false, 1));
+    s_part->setProperty("pluginsEnabled", TQVariant(false));
+    s_part->setProperty("javaScriptEnabled", TQVariant(false));
+    s_part->setProperty("javaEnabled", TQVariant(false));
 
     // doc->openStream( "text/html", KURL() );
     // doc->writeStream( TQCString( "<HTML><BODY>FOO</BODY></HTML>" ) );
