@@ -432,7 +432,7 @@ TEWidget::TEWidget(TQWidget *parent, const char *name)
   setAcceptDrops(true); // attempt
   dragInfo.state = diNone;
 
-  setFocusPolicy( TQ_WheelFocus );
+  setFocusPolicy( TQWidget::WheelFocus );
 
   // im
   setInputMethodEnabled(true);
@@ -636,11 +636,7 @@ void TEWidget::drawAttrStr(TQPainter &paint, TQRect rect,
       if (pm)
         paint.setBackgroundMode( Qt::TransparentMode );
       if (clear || (blinking && (attr->r & RE_BLINK))) {
-#ifdef USE_QT4
-        paint.eraseRect(rect);
-#else // USE_QT4
         erase(rect);
-#endif // USE_QT4
       }
     }
     else
@@ -651,7 +647,7 @@ void TEWidget::drawAttrStr(TQPainter &paint, TQRect rect,
         // draw background colors with 75% opacity
         if ( draw_translucent_background_colors && argb_visual && tqAlpha(blend_color) < 0xff )
         {
-          QRgb col = bColor.rgb();
+          TQRgb col = bColor.rgb();
 
           TQ_UINT8 salpha = 192;
           TQ_UINT8 dalpha = 255 - salpha;
@@ -1938,7 +1934,7 @@ bool TEWidget::eventFilter( TQObject *obj, TQEvent *e )
       TQT_TQKEYEVENT( e )->ignore();
       return false;
   }
-  if ( TQT_BASE_OBJECT(obj) != TQT_BASE_OBJECT(this) /* when embedded */ && TQT_BASE_OBJECT(obj) != TQT_BASE_OBJECT(parent()) /* when standalone */ )
+  if ( obj != this /* when embedded */ && obj != parent() /* when standalone */ )
       return false; // not us
   if ( e->type() == TQEvent::KeyPress )
   {
