@@ -6,6 +6,10 @@ Copyright (C) 2010 Timothy Pearson <kb9vqf@pearsoncomputing.net>
 Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 ******************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "shutdowndlg.h"
 
 #include <tqapplication.h>
@@ -33,7 +37,7 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #include <tdelocale.h>
 #include <tdeconfig.h>
 #include <tdeapplication.h>
-#ifdef __TDE_HAVE_TDEHWLIB
+#ifdef WITH_TDEHWLIB
 #include <tdehardwaredevices.h>
 #endif
 #include <kdebug.h>
@@ -707,7 +711,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 	TQVBoxLayout* vbox = new TQVBoxLayout( this );
 
 	if (m_selection) {
-		*m_selection = 0;
+		*m_selection = SuspendType::NotSpecified;
 	}
 
 	TQFrame* frame = new TQFrame( this );
@@ -758,15 +762,14 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		FlatButton* btnLogout = new FlatButton( frame );
 		btnLogout->setTextLabel( TQString("&") + i18n("Log out"), false );
 		btnLogout->setPixmap( DesktopIcon( "back") );
+		TQToolTip::add( btnLogout, i18n( "<qt><p>Log out of the current session to login as a different user.</p></qt>" ) );
 		int i = btnLogout->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 		btnLogout->setAccel( "ALT+" + btnLogout->textLabel().lower()[i+1] ) ;
 		hbuttonbox->addWidget ( btnLogout );
 		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
-
 	}
 	else
 	{
-
 		// konqy
 		lfrm = new TQFrame( frame );
 		lfrm->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
@@ -787,17 +790,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 		buttonlay->addStretch( 1 );
 		// End session
-		KPushButton* btnLogout = new KPushButton( KGuiItem( i18n("&End Current Session"), "edit-undo"), frame );
-				TQToolTip::add( btnLogout, i18n( "<qt><h3>End Current Session</h3><p>Log out of the current session to login with a different user</p></qt>" ) );
+		KPushButton* btnLogout = new KPushButton( KGuiItem( i18n("&Log out"), "edit-undo"), frame );
+		TQToolTip::add( btnLogout, i18n( "<qt><p>Log out of the current session to login as a different user.</p></qt>" ) );
 		btnFont = btnLogout->font();
 		buttonlay->addWidget( btnLogout );
 		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
 	}
 
-#ifdef COMPILE_HALBACKEND
-	m_halCtx = NULL;
-#endif
-
 	if ((maysd) || (mayrb)) {
 
 		// respect lock on resume & disable suspend/hibernate settings
@@ -810,87 +809,38 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		bool canFreeze = false;
 		bool canSuspend = false;
 		bool canHibernate = false;
+		bool canHybridSuspend = false;
 
-#if defined(COMPILE_HALBACKEND)
-		// Query HAL for suspend/resume support
-		m_halCtx = libhal_ctx_new();
-
-		DBusError error;
-		dbus_error_init(&error);
-		m_dbusConn = dbus_connection_open_private(DBUS_SYSTEM_BUS, &error);
-		if (!m_dbusConn)
-		{
-			dbus_error_free(&error);
-			libhal_ctx_free(m_halCtx);
-			m_halCtx = NULL;
-		}
-		else
-		{
-			dbus_bus_register(m_dbusConn, &error);
-			if (dbus_error_is_set(&error))
-			{
-				dbus_error_free(&error);
-				libhal_ctx_free(m_halCtx);
-				m_dbusConn = NULL;
-				m_halCtx = NULL;
-			}
-			else
-			{
-				libhal_ctx_set_dbus_connection(m_halCtx, m_dbusConn);
-				if (!libhal_ctx_init(m_halCtx, &error))
-				{
-					if (dbus_error_is_set(&error))
-						dbus_error_free(&error);
-					libhal_ctx_free(m_halCtx);
-					m_dbusConn = NULL;
-					m_halCtx = NULL;
-				}
-			}
-		}
-
-		if (m_halCtx)
-		{
-			if (libhal_device_get_property_bool(m_halCtx,
-												"/org/freedesktop/Hal/devices/computer",
-												"power_management.can_suspend",
-												NULL))
-			{
-				canSuspend = true;
-			}
-
-			if (libhal_device_get_property_bool(m_halCtx,
-												"/org/freedesktop/Hal/devices/computer",
-												"power_management.can_hibernate",
-												NULL))
-			{
-				canHibernate = true;
-			}
-		}
-#elif defined(__TDE_HAVE_TDEHWLIB) // COMPILE_HALBACKEND
+#if defined(WITH_TDEHWLIB)
 		TDERootSystemDevice* rootDevice = TDEGlobal::hardwareDevices()->rootSystemDevice();
 		if (rootDevice) {
 			canFreeze = rootDevice->canFreeze();
 			canSuspend = rootDevice->canSuspend();
 			canHibernate = rootDevice->canHibernate();
+			canHybridSuspend = rootDevice->canHybridSuspend();
 		}
 		else {
 			canFreeze = false;
 			canSuspend = false;
 			canHibernate = false;
+			canHybridSuspend = false;
 		}
-#endif // COMPILE_HALBACKEND
+#endif
 
 		if(doUbuntuLogout) {
-
+      // Ubuntu style logout window
 			if (canFreeze && !disableSuspend)
 			{
 				// Freeze
 				FlatButton* btnFreeze = new FlatButton( frame );
 				btnFreeze->setTextLabel( i18n("&Freeze"), false );
 				btnFreeze->setPixmap( DesktopIcon( "suspend") );
+				TQToolTip::add(btnFreeze, i18n("<qt><p>Put the computer in software idle mode,"
+				" allowing for some powersaving. The system can be reactivated in a really short time,"
+				" almost instantly.</p><p>This correspond to ACPI S0 mode.</p></qt>"));
 				int i = btnFreeze->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnFreeze->setAccel( "ALT+" + btnFreeze->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnFreeze);
+				hbuttonbox->addWidget ( btnFreeze );
 				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
 			}
 
@@ -900,9 +850,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				FlatButton* btnSuspend = new FlatButton( frame );
 				btnSuspend->setTextLabel( i18n("&Suspend"), false );
 				btnSuspend->setPixmap( DesktopIcon( "suspend") );
+				TQToolTip::add(btnSuspend, i18n("<qt><p>Put the computer in suspend-to-memory mode."
+				" The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze'"
+				" but requires longer time to reactivate the system.</p><p>This correspond to ACPI S3 mode.</p>"
+				"<p>Also known as Suspend-to-RAM mode.</p></qt>"));
 				int i = btnSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnSuspend->setAccel( "ALT+" + btnSuspend->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnSuspend);
+				hbuttonbox->addWidget ( btnSuspend );
 				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
 			}
 
@@ -912,12 +866,33 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				FlatButton* btnHibernate = new FlatButton( frame );
 				btnHibernate->setTextLabel( i18n("&Hibernate"), false );
 				btnHibernate->setPixmap( DesktopIcon( "hibernate") );
+				TQToolTip::add(btnHibernate, i18n("<qt><p>Put the computer in suspend-to-disk mode."
+				" The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but"
+				" considerable time is required to reactivate the system again.</p><p>This correspond to ACPI S4 mode.</p><p>Also known as Suspend-to-Disk mode.</p></qt>"));
 				int i = btnHibernate->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHibernate->setAccel( "ALT+" + btnHibernate->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnHibernate);
+				hbuttonbox->addWidget ( btnHibernate );
 				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
 			}
 
+			if (canHybridSuspend && !disableSuspend && !disableHibernate)
+			{
+				// Hybrid suspend
+				FlatButton* btnHybridSuspend = new FlatButton( frame );
+				btnHybridSuspend->setTextLabel( i18n("H&ybrid Suspend"), false );
+				btnHybridSuspend->setPixmap( DesktopIcon( "hibernate") );
+				TQToolTip::add(btnHybridSuspend, i18n("<qt><p>Put the computer in both suspend-to-memory and"
+				" suspend-to-disk mode. The system is stopped and its state saved to memory and to disk.</p>"
+				"<p>This offers the best of both 'Suspend' and 'Hibernate' modes combined together. The system is"
+				" de facto in 'Suspend' mode but if power is lost, work can still be resumed as if the system"
+				" had been hibernated, preventing any data loss.</p><p>This correspond to ACPI S3+S4 mode.</p>"
+				"<p>Also known as Suspend-to-RAM + Suspend-to-Disk mode.</p></qt>"));
+				int i = btnHybridSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
+				btnHybridSuspend->setAccel( "ALT+" + btnHybridSuspend->textLabel().lower()[i+1] ) ;
+				hbuttonbox->addWidget ( btnHybridSuspend );
+				connect(btnHybridSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotHybridSuspend()));
+			}
+			
 			// Separator (within buttonlay)
 			vbox->addWidget( new KSeparator( frame ) );
 
@@ -930,6 +905,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				FlatButton* btnReboot = new FlatButton( frame );
 				btnReboot->setTextLabel( i18n("&Restart"), false );
 				btnReboot->setPixmap( DesktopIcon( "reload") );
+				TQToolTip::add( btnReboot, i18n( "<qt><p>Log out of the current session and restart the computer.</p></qt>" ) );
 				int i = btnReboot->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnReboot->setAccel( "ALT+" + btnReboot->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnReboot);
@@ -968,8 +944,9 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			if (maysd) {
 				// Shutdown
 				FlatButton* btnHalt = new FlatButton( frame );
-				btnHalt->setTextLabel( i18n("&Turn Off"), false );
+				btnHalt->setTextLabel( i18n("&Shutdown"), false );
 				btnHalt->setPixmap( DesktopIcon( "system-log-out") );
+				TQToolTip::add( btnHalt, i18n( "<qt><p>Log out of the current session and turn off the computer.</p></qt>" ) );
 				int i = btnHalt->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHalt->setAccel( "ALT+" + btnHalt->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnHalt );
@@ -991,10 +968,11 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		}
 		else
 		{
+      // Standard style logout window
 			if (maysd) {
 				// Shutdown
-				KPushButton* btnHalt = new KPushButton( KGuiItem( i18n("&Turn Off Computer"), "system-log-out"), frame );
-				TQToolTip::add( btnHalt, i18n( "<qt><h3>Turn Off Computer</h3><p>Log out of the current session and turn off the computer</p></qt>" ) );
+				KPushButton* btnHalt = new KPushButton( KGuiItem( i18n("&Shutdown"), "system-log-out"), frame );
+				TQToolTip::add( btnHalt, i18n( "<qt><p>Log out of the current session and turn off the computer.</p></qt>" ) );
 				btnHalt->setFont( btnFont );
 				buttonlay->addWidget( btnHalt );
 				connect(btnHalt, TQT_SIGNAL(clicked()), TQT_SLOT(slotHalt()));
@@ -1005,8 +983,8 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			if (mayrb) {
 				// Reboot
-				KSMDelayedPushButton* btnReboot = new KSMDelayedPushButton( KGuiItem( i18n("&Restart Computer"), "reload"), frame );
-				TQToolTip::add( btnReboot, i18n( "<qt><h3>Restart Computer</h3><p>Log out of the current session and restart the computer</p><p>Hold the mouse button or the space bar for a short while to get a list of options what to boot</p></qt>" ) );
+				KSMDelayedPushButton* btnReboot = new KSMDelayedPushButton( KGuiItem( i18n("&Restart"), "reload"), frame );
+				TQToolTip::add( btnReboot, i18n( "<qt><p>Log out of the current session and restart the computer.</p></qt>" ) );
 				btnReboot->setFont( btnFont );
 				buttonlay->addWidget( btnReboot );
 
@@ -1042,8 +1020,10 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			if (canFreeze && !disableSuspend)
 			{
-				KPushButton* btnFreeze = new KPushButton( KGuiItem( i18n("&Freeze Computer"), "suspend"), frame );
-				TQToolTip::add(btnFreeze, i18n("<qt><h3>Freeze Computer</h3><p>Put the computer in software sleep mode, allowing for some powersaving. The system can be reactivated in a really short time, almost instantly.</p></qt>"));
+				KPushButton* btnFreeze = new KPushButton( KGuiItem( i18n("&Freeze"), "suspend"), frame );
+				TQToolTip::add(btnFreeze, i18n("<qt><p>Put the computer in software idle mode,"
+				" allowing for some powersaving. The system can be reactivated in a really short time,"
+				" almost instantly.</p><p>This correspond to ACPI S0 mode.</p></qt>"));
 				btnFreeze->setFont( btnFont );
 				buttonlay->addWidget( btnFreeze );
 				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
@@ -1051,8 +1031,11 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			if (canSuspend && !disableSuspend)
 			{
-				KPushButton* btnSuspend = new KPushButton( KGuiItem( i18n("&Suspend Computer"), "suspend"), frame );
-				TQToolTip::add(btnSuspend, i18n("<qt><h3>Suspend Computer</h3><p>Put the computer in a suspend-to-memory mode. The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze Computer' but requires longer time to reactivate the system.</p></qt>"));
+				KPushButton* btnSuspend = new KPushButton( KGuiItem( i18n("&Suspend"), "suspend"), frame );
+				TQToolTip::add(btnSuspend, i18n("<qt><p>Put the computer in suspend-to-memory mode."
+				" The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze'"
+				" but requires longer time to reactivate the system.</p><p>This correspond to ACPI S3 mode.</p>"
+				"<p>Also known as Suspend-to-RAM mode.</p></qt>"));
 				btnSuspend->setFont( btnFont );
 				buttonlay->addWidget( btnSuspend );
 				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
@@ -1060,13 +1043,29 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			if (canHibernate && !disableHibernate)
 			{
-				KPushButton* btnHibernate = new KPushButton( KGuiItem( i18n("&Hibernate Computer"), "hibernate"), frame );
-				TQToolTip::add(btnHibernate, i18n("<qt><h3>Hibernate Computer</h3><p>Put the computer in a suspend-to-disk mode. The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but considerable time is required to reactivate the system again.</p></qt>"));
+				KPushButton* btnHibernate = new KPushButton( KGuiItem( i18n("&Hibernate"), "hibernate"), frame );
+				TQToolTip::add(btnHibernate, i18n("<qt><p>Put the computer in suspend-to-disk mode."
+				" The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but"
+				" considerable time is required to reactivate the system again.</p><p>This correspond to ACPI S4 mode.</p><p>Also known as Suspend-to-Disk mode.</p></qt>"));
 				btnHibernate->setFont( btnFont );
 				buttonlay->addWidget( btnHibernate );
 				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
 			}
 
+			if (canHybridSuspend && !disableSuspend && !disableHibernate)
+			{
+				KPushButton* btnHybridSuspend = new KPushButton( KGuiItem( i18n("H&ybrid Suspend"), "hibernate"), frame );
+				TQToolTip::add(btnHybridSuspend, i18n("<qt><p>Put the computer in both suspend-to-memory and"
+				" suspend-to-disk mode. The system is stopped and its state saved to memory and to disk.</p>"
+				"<p>This offers the best of both 'Suspend' and 'Hibernate' modes combined together. The system is"
+				" de facto in 'Suspend' mode but if power is lost, work can still be resumed as if the system"
+				" had been hibernated, preventing any data loss.</p><p>This correspond to ACPI S3+S4 mode.</p>"
+				"<p>Also known as Suspend-to-RAM + Suspend-to-Disk mode.</p></qt>"));
+				btnHybridSuspend->setFont( btnFont );
+				buttonlay->addWidget( btnHybridSuspend );
+				connect(btnHybridSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotHybridSuspend()));
+			}
+			
 			buttonlay->addStretch( 1 );
 
 			// Separator
@@ -1076,9 +1075,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			KPushButton* btnBack = new KPushButton( KStdGuiItem::cancel(), frame );
 			buttonlay->addWidget( btnBack );
 			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
-
 		}
-
 	}
 	else {
 		// finish the dialog correctly
@@ -1105,25 +1102,12 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
 		}
-
-
 	}
-
-
 }
 
 
 KSMShutdownDlg::~KSMShutdownDlg()
 {
-#ifdef COMPILE_HALBACKEND
-	if (m_halCtx)
-	{
-		DBusError error;
-		dbus_error_init(&error);
-		libhal_ctx_shutdown(m_halCtx, &error);
-		libhal_ctx_free(m_halCtx);
-	}
-#endif
 }
 
 
@@ -1160,53 +1144,26 @@ void KSMShutdownDlg::slotHalt()
 
 void KSMShutdownDlg::slotSuspend()
 {
-#ifndef COMPILE_HALBACKEND
-	*m_selection = 1;	// Suspend
-#else
-	if (m_dbusConn)
-	{
-		DBusMessage *msg = dbus_message_new_method_call(
-							  "org.freedesktop.Hal",
-							  "/org/freedesktop/Hal/devices/computer",
-							  "org.freedesktop.Hal.Device.SystemPowerManagement",
-							  "Suspend");
-
-		int wakeup=0;
-		dbus_message_append_args(msg, DBUS_TYPE_INT32, &wakeup, DBUS_TYPE_INVALID);
-
-		dbus_connection_send(m_dbusConn, msg, NULL);
-
-		dbus_message_unref(msg);
-	}
-#endif
+	*m_selection = SuspendType::Suspend;
 	reject(); // continue on resume
 }
 
 void KSMShutdownDlg::slotHibernate()
 {
-#ifndef COMPILE_HALBACKEND
-	*m_selection = 2;	// Hibernate
-#else
-	if (m_dbusConn)
-	{
-		DBusMessage *msg = dbus_message_new_method_call(
-							  "org.freedesktop.Hal",
-							  "/org/freedesktop/Hal/devices/computer",
-							  "org.freedesktop.Hal.Device.SystemPowerManagement",
-							  "Hibernate");
-
-		dbus_connection_send(m_dbusConn, msg, NULL);
-
-		dbus_message_unref(msg);
-	}
-#endif
+	*m_selection = SuspendType::Hibernate;
 	reject(); // continue on resume
 }
 
 void KSMShutdownDlg::slotFreeze()
 {
-	*m_selection = 3;	// Freeze
-	reject();
+	*m_selection = SuspendType::Freeze;
+	reject(); // continue on resume
+}
+
+void KSMShutdownDlg::slotHybridSuspend()
+{
+	*m_selection = SuspendType::HybridSuspend;
+	reject(); // continue on resume
 }
 
 bool KSMShutdownDlg::confirmShutdown( bool maysd, bool mayrb, TDEApplication::ShutdownType& sdtype, TQString& bootOption, int* selection )
@@ -1479,7 +1436,7 @@ void FlatButton::init()
 	setUsesBigPixmap(true);
 	setAutoRaise(true);
 	setTextPosition( TQToolButton::Under );
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
  }
 
 
