@@ -463,7 +463,7 @@ void QuartzButton::drawButton(TQPainter *p)
 	{
 		int xOff = (width()-10)/2;
 		int yOff = (height()-10)/2;
-		p->setPen( Qt::black );
+		p->setPen( TQt::black );
 		p->drawPixmap(isDown() ? xOff+2: xOff+1, isDown() ? yOff+2 : yOff+1, *deco);
 		p->setPen( KDecoration::options()->color(KDecoration::ColorButtonBg, decoration()->isActive()).light(150) );
 		p->drawPixmap(isDown() ? xOff+1: xOff, isDown() ? yOff+1 : yOff, *deco);
@@ -723,7 +723,7 @@ void QuartzClient::paintEvent( TQPaintEvent* )
     // Draw the title bar.
     // ===================
     int r_x, r_y, r_x2, r_y2;
-    TQT_TQRECT_OBJECT(widget()->rect()).coords(&r_x, &r_y, &r_x2, &r_y2);
+    widget()->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
     const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
     const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
     const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
