@@ -606,7 +606,7 @@ void ButtonDropSite::drawContents( TQPainter* p )
 
 	TQColor c1( 0x0A, 0x5F, 0x89 );		// KDE 2 titlebar default colour
 	p->fillRect( r, c1 );
-	p->setPen( Qt::white );
+	p->setPen( TQt::white );
 	p->setFont( TQFont( TDEGlobalSettings::generalFont().family(), 12, TQFont::Bold) );
 	p->drawText( r, AlignLeft | AlignVCenter, i18n("TDE") );
 
@@ -879,5 +879,3 @@ void ButtonPositionWidget::setButtonsRight(const TQString &buttons)
 }
 
 #include "buttons.moc"
-// vim: ts=4
-// kate: space-indent off; tab-width 4;
