@@ -72,7 +72,7 @@ typedef TQValueList<SystemTrayWindow> SystemTrayWindowList;
 
 class Workspace : public TQObject, public KWinInterface, public KDecorationDefines
     {
-    Q_OBJECT
+    TQ_OBJECT
     public:
         Workspace( bool restore = FALSE );
         virtual ~Workspace();
@@ -156,7 +156,10 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void clientHidden( Client*  );
         void clientAttentionChanged( Client* c, bool set );
 
-        void clientMoved(const TQPoint &pos, Time time);
+        void checkActiveBorder(const TQPoint &pos, Time time);
+        void reserveActiveBorder(ActiveBorder border);
+        void unreserveActiveBorder(ActiveBorder border);
+        void reserveActiveBorderSwitching(bool reserve);
 
         /**
          * Returns the current virtual desktop of this workspace
@@ -167,7 +170,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
          */
         int numberOfDesktops() const;
         void setNumberOfDesktops( int n );
-        
+
         int activeScreen() const;
         int numScreens() const;
         void checkActiveScreen( const Client* c );
@@ -254,7 +257,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
 
         void sendPingToWindow( Window w, Time timestamp ); // called from Client::pingWindow()
         void sendTakeActivity( Client* c, Time timestamp, long flags ); // called from Client::takeActivity()
-        
+
         bool kompmgrIsRunning();
         void setOpacity(unsigned long winId, unsigned int opacityPercent);
         void setShadowSize(unsigned long winId, unsigned int shadowSizePercent);
@@ -273,7 +276,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void focusToNull(); // SELI public?
         enum FocusChainChange { FocusChainMakeFirst, FocusChainMakeLast, FocusChainUpdate };
         void updateFocusChains( Client* c, FocusChainChange change );
-        
+
         bool forcedGlobalMouseGrab() const;
         void clientShortcutUpdated( Client* c );
         bool shortcutAvailable( const TDEShortcut& cut, Client* ignore = NULL ) const;
@@ -302,7 +305,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void requestDelayFocus( Client* );
         void updateFocusMousePosition( const TQPoint& pos );
         TQPoint focusMousePosition() const;
-        
+
         void toggleTopDockShadows(bool on);
 
     public slots:
@@ -387,7 +390,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void setupWindowShortcutDone( bool );
 
         void updateClientArea();
-        
+
         // kompmgr, also dcop
         void startKompmgr();
 
@@ -406,6 +409,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void cleanupTemporaryRules();
         void writeWindowRules();
         void kipcMessage( int id, int data );
+        void updateActiveBorders();
         // kompmgr
         void setPopupClientOpacity(int v);
         void resetClientOpacity();
@@ -486,15 +490,13 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void tabBoxKeyPress( const KKeyNative& keyX );
         void tabBoxKeyRelease( const XKeyEvent& ev );
 
-    // electric borders
-        void checkElectricBorders( bool force = false );
-        void createBorderWindows();
-        void destroyBorderWindows();
-        bool electricBorder(XEvent * e);
-        void raiseElectricBorders();
+    // active borders
+        void destroyActiveBorders();
+        bool activeBorderEvent(XEvent *e);
+        void activeBorderSwitchDesktop(ActiveBorder border, const TQPoint& pos);
 
     // ------------------
-    
+
         void helperDialog( const TQString& message, const Client* c );
 
         void calcDesktopLayout(int &x, int &y) const;
@@ -550,7 +552,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         ClientList global_focus_chain; // this one is only for things like tabbox's MRU
         ClientList should_get_focus; // last is most recent
         ClientList attention_chain;
-        
+
         bool showing_desktop;
         ClientList showing_desktop_clients;
         int block_showing_desktop;
@@ -617,21 +619,19 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
 
         TDEStartupInfo* startup;
 
-        bool electric_have_borders;
-        int electric_current_border;
-        WId electric_top_border;
-        WId electric_bottom_border;
-        WId electric_left_border;
-        WId electric_right_border;
-        int electricLeft;
-        int electricRight;
-        int electricTop;
-        int electricBottom;
-        Time electric_time_first;
-        Time electric_time_last;
-        TQPoint electric_push_point;
+        ActiveBorder active_current_border;
+        Window active_windows[ ACTIVE_BORDER_COUNT ];
+        int activeLeft;
+        int activeRight;
+        int activeTop;
+        int activeBottom;
+        Time active_time_first;
+        Time active_time_last;
+        Time active_time_last_trigger;
+        TQPoint active_push_point;
+        int active_reserved[ ACTIVE_BORDER_COUNT ]; // corners/edges used by something
 
-        Qt::Orientation layoutOrientation;
+        TQt::Orientation layoutOrientation;
         int layoutX;
         int layoutY;
 
@@ -654,7 +654,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         bool forced_global_mouse_grab;
         friend class StackingUpdatesBlocker;
         friend class Client;
-        
+
         //kompmgr
         TQSlider *transSlider;
         TQPushButton *transButton;
@@ -663,7 +663,11 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         int maximizedWindowCounter;
         int topDockShadowSize;*/
         //end
-        
+
+        Window outline_left;
+        Window outline_right;
+        Window outline_top;
+        Window outline_bottom;
      signals:
         void kompmgrStarted();
         void kompmgrStopped();
